@@ -172,7 +172,9 @@ class LookerClient:
 
         url = utils.compose_url(self.api_url, path=["versions"])
 
-        response = httpx.get(url=url, timeout=TIMEOUT_SEC)
+        response = httpx.get(
+            url=url, timeout=TIMEOUT_SEC, headers=self.async_client.headers
+        )
         try:
             response.raise_for_status()
         except httpx.HTTPStatusError as error:
@@ -651,7 +653,7 @@ class LookerClient:
 
         return response.json()["fields"]["dimensions"]
 
-    @backoff.on_exception(backoff.expo, BACKOFF_EXCEPTIONS, max_tries=5)
+    @backoff.on_exception(backoff.expo, BACKOFF_EXCEPTIONS, max_tries=8)
     async def create_query(
         self,
         model: str,
@@ -717,6 +719,7 @@ class LookerClient:
         )
         return result
 
+    @backoff.on_exception(backoff.expo, BACKOFF_EXCEPTIONS, max_tries=8)
     async def create_query_task(self, query_id: str) -> str:
         """Runs a previously created query asynchronously and returns the query task ID.
 
